/**
** This software is distributed under the terms of the General Public License.  
** 
** Program : BuildIT!
** Version : 0.2
** Authors : Artur Prusakiewicz <prusak@mat.uni.torun.pl>
**	     Michal Switala <scisly@mat.uni.torun.pl>
** E-MAIL  : build@mat.uni.torun.pl
** WWW     : http://www.mat.uni.torun.pl/~scisly/buildit/
**           http://www.mat.uni.torun.pl/~prusak/buildit/
**/
#include "Tree.h"
#include "../components/MyLabel.h"


#include <qframe.h>
#include <qwidget.h>
#include <qlabel.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qpushbt.h>
#include <qscrollview.h>
#include <qlistview.h>


/*!
  \class ShowTree
  \brief Display window with component tree structure

  This class is used to show the component tree structure of created project
*/

class ShowTree : public QWidget 
{
  Q_OBJECT
public:
  /*!
    Constructor of class ShowTree. <br>
    \e t is a pointer to MyTree which has all components of created project <br>
    \e sysdirectory is a directory to <b> BuildIT! </b> directory with Images
    \e st sets display style: 0 - Windows,  1 - Motif
  */
  ShowTree(MyTree *t, QString sysdirectory, int st);

  /*! 
    This function display MyTree structure of components in the choosen style
  */
  void displayTree(bool first);

private slots:
  void refreshButton();
  void closeButton(); 
private:
  /*!
    This function is using by function displayTree() to display structure of components in Windows or Motif  style
  */
  bool updateTreePic(MyTree *t, QListViewItem *lv);

  /*!
    \internal
  */
  QListView *list;
  /*!
    \internal
  */
  QScrollView *scrview;
  /*!
    Main frame for ShowTree window
  */
  QFrame *mainframe;
  
  /*!
    Frame where tree is painting
  */
  QFrame *classframe;
  /*!
    "Refresh" button
  */
  QPushButton *refreshb;
  /*!
    "Close" button
  */
  QPushButton *closeb;
  /*!
    MyTree structure of components to show 
  */
  MyTree *treetab;
  /*! 
    Used to refres
  */
  int wx;
  /*!
    Used to refresh
  */
  int wy;

  /*!
    0 - BuildIT! style
    1 - Windows style
    2 - Motif style
  */
  int style; 
  /*!
    \internal
  */
  QString sysDir;
};
